Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(37)

Unified Diff: third_party/WebKit/public/web/WebAXObject.h

Issue 2858493002: Rename AXObject to AXObjectImpl in modules/ and web/ (Closed)
Patch Set: Fixed rebase Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « third_party/WebKit/Source/web/WebViewImpl.cpp ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: third_party/WebKit/public/web/WebAXObject.h
diff --git a/third_party/WebKit/public/web/WebAXObject.h b/third_party/WebKit/public/web/WebAXObject.h
index 2820d630c564966de12c5e93913956e1b6a1a25f..e2055ca3377be902a332fa501faf660862dcdd13 100644
--- a/third_party/WebKit/public/web/WebAXObject.h
+++ b/third_party/WebKit/public/web/WebAXObject.h
@@ -43,7 +43,7 @@ class SkMatrix44;
namespace blink {
-class AXObject;
+class AXObjectImpl;
class ScopedAXObjectCache;
class WebAXObject;
class WebNode;
@@ -81,7 +81,7 @@ class WebScopedAXContext {
std::unique_ptr<ScopedAXObjectCache> private_;
};
// A container for passing around a reference to AXObject.
class WebAXObject {
public:
~WebAXObject() { Reset(); }
@@ -353,13 +353,13 @@ class WebAXObject {
BLINK_EXPORT void ScrollToGlobalPoint(const WebPoint&) const;
#if BLINK_IMPLEMENTATION
- WebAXObject(AXObject*);
- WebAXObject& operator=(AXObject*);
- operator AXObject*() const;
+ WebAXObject(AXObjectImpl*);
+ WebAXObject& operator=(AXObjectImpl*);
+ operator AXObjectImpl*() const;
#endif
private:
- WebPrivatePtr<AXObject> private_;
+ WebPrivatePtr<AXObjectImpl> private_;
};
} // namespace blink
« no previous file with comments | « third_party/WebKit/Source/web/WebViewImpl.cpp ('k') | no next file » | no next file with comments »
@@ -81,7 +81,7 @@ class WebScopedAXContext {
std::unique_ptr<ScopedAXObjectCache> private_;
};
-// A container for passing around a reference to AXObject.
+// A container for passing around a reference to AXObjectImpl.
class WebAXObject {
public:

Powered by Google App Engine
This is Rietveld 408576698